orcid\_api package
==================

Subpackages
-----------

.. toctree::

    orcid_api.apis
    orcid_api.models

Submodules
----------

orcid\_api\.api\_client module
------------------------------

.. automodule:: orcid_api.api_client
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.configuration module
--------------------------------

.. automodule:: orcid_api.configuration
    :members:
    :undoc-members:
    :show-inheritance:

orcid\_api\.rest module
-----------------------

.. automodule:: orcid_api.rest
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: orcid_api
    :members:
    :undoc-members:
    :show-inheritance:
